@@ -13,7 +13,6 @@
 #include "kdfconfig.h"
 
 #include <KConfigGroup>
-#include <KLineEdit>
 
 #include <QCheckBox>
 #include <QCloseEvent>
@@ -55,9 +54,9 @@ KDFConfigWidget::KDFConfigWidget(QWidget *parent, bool init)
                  this, &KDFConfigWidget::toggleListText );
         connect( m_listWidget, &QTreeWidget::itemClicked,
                  this, &KDFConfigWidget::slotChanged );
-
-        iconVisible = MainBarIcon( QStringLiteral( "dialog-ok-apply" ) );
-        iconHidden = MainBarIcon( QStringLiteral( "dialog-cancel" ) );
+        const int smallIcon = qApp->style()->pixelMetric(QStyle::PM_ToolBarIconSize);
+        iconVisible = QIcon::fromTheme( QStringLiteral( "dialog-ok-apply" ) ).pixmap(smallIcon);
+        iconHidden = QIcon::fromTheme( QStringLiteral( "dialog-cancel" ) ).pixmap(smallIcon);
 
         QTreeWidgetItem * item = new QTreeWidgetItem( m_listWidget );
         for( int i=0; i < m_columnList.size(); i++ )
@@ -72,9 +71,20 @@ KDFConfigWidget::KDFConfigWidget(QWidget *parent, bool init)
 
         connect(mFileManagerEdit,&QLineEdit::textChanged,this,&KDFConfigWidget::slotChanged);
 
+        connect(mSystemFileManagerCheck,&QAbstractButton::toggled,this,&KDFConfigWidget::slotChanged);
+        connect(mSystemFileManagerCheck,&QAbstractButton::toggled,mFileManagerEdit,&QWidget::setDisabled);
+        connect(mSystemFileManagerCheck,&QAbstractButton::toggled,fileManagerEdit,&QWidget::setDisabled);
+
         connect(mOpenMountCheck,&QAbstractButton::toggled,this,&KDFConfigWidget::slotChanged);
 
         connect(mPopupFullCheck,&QAbstractButton::toggled,this,&KDFConfigWidget::slotChanged);
+
+        if(!QStandardPaths::locate(QStandardPaths::RuntimeLocation, QLatin1String("flatpak-info")).isEmpty())
+        {
+            mFlatpakLabel->setVisible( true );
+            mSystemFileManagerCheck->setEnabled( false );
+            mFileManagerEdit->setEnabled( false );
+        }
     }
 
     loadSettings();
@@ -110,6 +120,7 @@ void KDFConfigWidget::applySettings( void )
         mStd.setUpdateFrequency( m_updateSpinBox->value() );
         mStd.setPopupIfFull( mPopupFullCheck->isChecked() );
         mStd.setOpenFileManager( mOpenMountCheck->isChecked() );
+        mStd.setUseSystemFileManager( mSystemFileManagerCheck->isChecked() );
         mStd.writeConfiguration();
 
         QTreeWidgetItem * item = m_listWidget->topLevelItem(0);
@@ -138,8 +149,12 @@ void KDFConfigWidget::loadSettings( void )
         m_updateSpinBox->setValue( mStd.updateFrequency() );
         mPopupFullCheck->setChecked( mStd.popupIfFull() );
         mOpenMountCheck->setChecked( mStd.openFileManager() );
+        mSystemFileManagerCheck->setChecked( mStd.useSystemFileManager() );
         mFileManagerEdit->setText( mStd.fileManager() );
 
+        mFileManagerEdit->setEnabled( !mStd.useSystemFileManager() );
+        fileManagerEdit->setEnabled( !mStd.useSystemFileManager() );
+
         QTreeWidgetItem * item = m_listWidget->topLevelItem(0);
         for( int i=0; i < m_columnList.size(); i++ )
         {
@@ -160,6 +175,7 @@ void KDFConfigWidget::defaultsBtnClicked( void )
     m_updateSpinBox->setValue( mStd.updateFrequency() );
     mPopupFullCheck->setChecked( mStd.popupIfFull() );
     mOpenMountCheck->setChecked( mStd.openFileManager() );
+    mSystemFileManagerCheck->setChecked( mStd.useSystemFileManager() );
     mFileManagerEdit->setText( mStd.fileManager() );
 
     QTreeWidgetItem * item = m_listWidget->topLevelItem(0);
