@@ -31,6 +31,8 @@
 #include <QPainter>
 #include <QMenu>
 #include <QProcess>
+#include <QDesktopServices>
+#include <QUrl>
 
 //This aren't used here...
 //#define BAR_COLUMN   7
@@ -210,7 +212,7 @@ void KDFWidget::loadSettings( void )
 **/
 void KDFWidget::settingsBtnClicked( void )
 {
-    if( mIsTopLevel == true )
+    if( mIsTopLevel )
     {
         if( mOptionDialog == nullptr )
         {
@@ -330,15 +332,16 @@ void KDFWidget::updateDFDone( void ){
 
 QIcon KDFWidget::generateIcon( const QString &iconName, bool mode, bool mounted)
 {
-    QPixmap pix = SmallIcon(iconName);
+    const int smallIcon = qApp->style()->pixelMetric(QStyle::PM_SmallIconSize);
+    QPixmap pix = QIcon::fromTheme( iconName ).pixmap(smallIcon);
 
     QPainter painter(&pix);
 
     if( mode )
-        painter.drawPixmap( QRect(0,6,10,10), SmallIcon(QStringLiteral( "object-locked" )) );
+        painter.drawPixmap( QRect(0,6,10,10), QIcon::fromTheme(QStringLiteral( "object-locked" )).pixmap(smallIcon) );
 
     if( mounted )
-        painter.drawPixmap( QRect(6,6,12,12) , SmallIcon(QStringLiteral( "emblem-mounted" )) );
+        painter.drawPixmap( QRect(6,6,12,12) , QIcon::fromTheme(QStringLiteral( "emblem-mounted" )).pixmap(smallIcon) );
 
     painter.end();
     return QIcon(pix);
@@ -347,11 +350,11 @@ QIcon KDFWidget::generateIcon( const QString &iconName, bool mode, bool mounted)
 
 void KDFWidget::criticallyFull( DiskEntry *disk )
 {
-    if( mStd.popupIfFull() == true )
+    if( mStd.popupIfFull() )
     {
         QString msg = i18n("Device [%1] on [%2] is critically full.",
                            disk->deviceName(), disk->mountPoint());
-        KMessageBox::sorry( this, msg, i18nc("Warning device getting critically full", "Warning"));
+        KMessageBox::error( this, msg, i18nc("Warning device getting critically full", "Warning"));
     }
 }
 
@@ -425,14 +428,14 @@ void KDFWidget::contextMenuRequested( const QPoint &p )
         FreeItem->setText( i18n("MOUNTING") );
 
         QStandardItem * IconItem = m_listModel->item( index.row() , IconCol );
-        IconItem->setIcon( SmallIcon(QLatin1String( "user-away" )) );
+        IconItem->setIcon( QIcon::fromTheme(QStringLiteral( "user-away" )) );
 
         int val = disk->toggleMount();
         if( val != 0 /*== false*/ )
         {
             KMessageBox::error( this, disk->lastSysError() );
         }
-        else if ( ( mStd.openFileManager() == true)
+        else if ( mStd.openFileManager()
                   && (position == mountPointAction) ) //only on mount
         {
             openFileManager = true;
@@ -446,10 +449,14 @@ void KDFWidget::contextMenuRequested( const QPoint &p )
         openFileManager = true;
     }
 
-    if( openFileManager == true )
+    if( openFileManager )
     {
         qCDebug(KDF) << "opening filemanager";
-        if(  mStd.fileManager().isEmpty() == false )
+        if( mStd.useSystemFileManager() )
+        {
+            QDesktopServices::openUrl( QUrl::fromLocalFile( disk->mountPoint() ) );
+        }
+        else if( !mStd.fileManager().isEmpty() )
         {
             QString cmd = mStd.fileManager();
             int pos = cmd.indexOf(QLatin1String( "%m" ));
