@@ -13,8 +13,6 @@
 #include "mntconfig.h"
 
 #include <KMessageBox>
-#include <KLineEdit>
-#include <KCModule>
 #include <KIconLoader>
 #include <KConfigGroup>
 #include <KSharedConfig>
@@ -239,7 +237,7 @@ void MntConfigWidget::selectMntFile()
 
     if( !url.isLocalFile() )
     {
-        KMessageBox::sorry( nullptr, i18n( "Only local files supported." ) );
+        KMessageBox::error( nullptr, i18n( "Only local files supported." ) );
         return;
     }
 
@@ -255,7 +253,7 @@ void MntConfigWidget::selectUmntFile()
 
     if( !url.isLocalFile() )
     {
-        KMessageBox::sorry( nullptr, i18n( "Only local files are currently supported." ) );
+        KMessageBox::error( nullptr, i18n( "Only local files are currently supported." ) );
         return;
     }
 
